pub fn status_code_for_error(err: &SessionError) -> u16Expand description
HTTP status code that should be returned for each session error type.
pub fn status_code_for_error(err: &SessionError) -> u16HTTP status code that should be returned for each session error type.